@@ -229,6 +229,7 @@ static PyObject *_PylibMC_RunSetCommand(PylibMC_Client *self,
                     break;
                 case MEMCACHED_FAILURE:
                 case MEMCACHED_NO_KEY_PROVIDED:
+                case MEMCACHED_BAD_KEY_PROVIDED:
                 case MEMCACHED_MEMORY_ALLOCATION_FAILURE:
                 case MEMCACHED_NOTSTORED:
                     retval = Py_False;
@@ -294,6 +295,7 @@ static PyObject *PylibMC_Client_delete(PylibMC_Client *self, PyObject *args) {
             case MEMCACHED_FAILURE:
             case MEMCACHED_NOTFOUND:
             case MEMCACHED_NO_KEY_PROVIDED:
+            case MEMCACHED_BAD_KEY_PROVIDED:
                 Py_RETURN_FALSE;
                 break;
             default:
@@ -424,7 +426,8 @@ static PyObject *PylibMC_Client_get_multi(PylibMC_Client *self, PyObject *args,
                     && !PyErr_Occurred()) {
                 if (curr_val == NULL && rc == MEMCACHED_END) {
                     break;
-                } else if (rc == MEMCACHED_NO_KEY_PROVIDED) {
+                } else if (rc == MEMCACHED_BAD_KEY_PROVIDED
+                        || rc == MEMCACHED_NO_KEY_PROVIDED) {
                     /* Do nothing at all. :-) */
                 } else if (rc != MEMCACHED_SUCCESS) {
                     Py_DECREF(retval);
@@ -673,8 +676,35 @@ static PyObject *PylibMC_Client_set_behaviors(PylibMC_Client *self,
 error:
     return NULL;
 }
-/* }}} */
 
+static PyObject *PylibMC_Client_flush_all(PylibMC_Client *self,
+        PyObject *args, PyObject *kwds) {
+    memcached_return rc;
+    time_t expire = 0;
+    PyObject *time = NULL;
+
+    static char *kws[] = { "time", NULL };
+
+    if (!PyArg_ParseTupleAndKeywords(args, kwds, "|O!", kws,
+                                     &PyInt_Type, &time))
+        return NULL;
+
+    if (time != NULL)
+        expire = PyInt_AS_LONG(time);
+
+    expire = (expire > 0) ? expire : 0;
+
+    rc = memcached_flush(self->mc, expire);
+    if (rc != MEMCACHED_SUCCESS)
+        return PylibMC_ErrFromMemcached(self, "delete_multi", rc);
+
+    Py_RETURN_TRUE;
+}
+
+static PyObject *PylibMC_Client_disconnect_all(PylibMC_Client *self) {
+    memcached_quit(self->mc);
+    Py_RETURN_NONE;
+}
 /* }}} */
 
 static PyObject *PylibMC_ErrFromMemcached(PylibMC_Client *self, const char *what,
