@@ -123,21 +123,20 @@ static void PylibMC_ClientType_dealloc(PylibMC_Client *);
 static int PylibMC_Client_init(PylibMC_Client *, PyObject *, PyObject *);
 static PyObject *PylibMC_Client_get(PylibMC_Client *, PyObject *arg);
 static PyObject *PylibMC_Client_set(PylibMC_Client *, PyObject *, PyObject *);
-static PyObject *PylibMC_Client_replace(PylibMC_Client *, PyObject *,
-        PyObject *);
+static PyObject *PylibMC_Client_replace(PylibMC_Client *, PyObject *, PyObject *);
 static PyObject *PylibMC_Client_add(PylibMC_Client *, PyObject *, PyObject *);
-static PyObject *PylibMC_Client_prepend(PylibMC_Client *, PyObject *,
-        PyObject *);
+static PyObject *PylibMC_Client_prepend(PylibMC_Client *, PyObject *, PyObject *);
 static PyObject *PylibMC_Client_append(PylibMC_Client *, PyObject *, PyObject *);
 static PyObject *PylibMC_Client_delete(PylibMC_Client *, PyObject *);
 static PyObject *PylibMC_Client_incr(PylibMC_Client *, PyObject *);
 static PyObject *PylibMC_Client_decr(PylibMC_Client *, PyObject *);
 static PyObject *PylibMC_Client_get_multi(PylibMC_Client *, PyObject *, PyObject *);
 static PyObject *PylibMC_Client_set_multi(PylibMC_Client *, PyObject *, PyObject *);
-static PyObject *PylibMC_Client_delete_multi(PylibMC_Client *, PyObject *,
-        PyObject *);
+static PyObject *PylibMC_Client_delete_multi(PylibMC_Client *, PyObject *, PyObject *);
 static PyObject *PylibMC_Client_get_behaviors(PylibMC_Client *);
 static PyObject *PylibMC_Client_set_behaviors(PylibMC_Client *, PyObject *);
+static PyObject *PylibMC_Client_flush_all(PylibMC_Client *, PyObject *, PyObject *);
+static PyObject *PylibMC_Client_disconnect_all(PylibMC_Client *);
 static PyObject *PylibMC_ErrFromMemcached(PylibMC_Client *, const char *,
         memcached_return);
 static PyObject *_PylibMC_Unpickle(const char *, size_t);
@@ -176,6 +175,10 @@ static PyMethodDef PylibMC_ClientType_methods[] = {
         "Get behaviors dict."},
     {"set_behaviors", (PyCFunction)PylibMC_Client_set_behaviors, METH_O,
         "Set behaviors dict."},
+    {"flush_all", (PyCFunction)PylibMC_Client_flush_all,
+        METH_VARARGS|METH_KEYWORDS, "Flush all data on all servers."},
+    {"disconnect_all", (PyCFunction)PylibMC_Client_disconnect_all, METH_NOARGS,
+        "Disconnect from all servers and reset own state."},
     {NULL, NULL, 0, NULL}
 };
 /* }}} */
